==> cosec-core-1.12.3-sources.jar: me/ahoo/cosec/policy/condition/part/RegularConditionMatcher.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.cosec.policy.condition.part

import me.ahoo.cosec.api.configuration.Configuration
import me.ahoo.cosec.api.policy.ConditionMatcher
import me.ahoo.cosec.policy.condition.ConditionMatcherFactory
import me.ahoo.cosec.policy.getMatcherPattern

class RegularConditionMatcher(configuration: Configuration) :
    PartConditionMatcher(RegularConditionMatcherFactory.TYPE, configuration) {
    private val matcher: Regex = configuration.getMatcherPattern().toRegex(RegexOption.IGNORE_CASE)

    override fun matchPart(partValue: String): Boolean {
        return matcher.matches(partValue)
    }
}

class RegularConditionMatcherFactory : ConditionMatcherFactory {
    companion object {
        const val TYPE = "reg"
    }

    override val type: String
        get() = TYPE

    override fun create(configuration: Configuration): ConditionMatcher {
        return RegularConditionMatcher(configuration)
    }
}

==> cosec-core-1.16.8-sources.jar: me/ahoo/cosec/policy/condition/part/RegularConditionMatcher.kt <==
/*
 * Copyright [2021-present] [ahoo wang <ahoowang@qq.com> (https://github.com/Ahoo-Wang)].
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package me.ahoo.cosec.policy.condition.part

import me.ahoo.cosec.api.configuration.Configuration
import me.ahoo.cosec.api.policy.ConditionMatcher
import me.ahoo.cosec.policy.condition.ConditionMatcherFactory

class RegularConditionMatcher(configuration: Configuration) :
    PartConditionMatcher(RegularConditionMatcherFactory.TYPE, configuration) {
    private val pattern: Regex = configuration.getRequired(RegularConditionMatcher::pattern.name).asString()
        .toRegex(RegexOption.IGNORE_CASE)

    override fun matchPart(partValue: String): Boolean {
        return pattern.matches(partValue)
    }
}

class RegularConditionMatcherFactory : ConditionMatcherFactory {
    companion object {
        const val TYPE = "regular"
    }

    override val type: String
        get() = TYPE

    override fun create(configuration: Configuration): ConditionMatcher {
        return RegularConditionMatcher(configuration)
    }
}
